@@ -7,6 +7,7 @@ GPL Licensed
 import sys, os, taurus, fandango, PyTango, getpass, traceback, time
 import fandango as fd
 from fandango.qt import Qt, QtCore, QtGui, DoubleClickable
+from taurus.external.qt.QtGui import QWidget
 
 from taurus.qt.qtgui.base.taurusbase import TaurusBaseComponent
 from taurus.qt.qtgui.base.taurusbase import TaurusBaseWidget
@@ -29,17 +30,10 @@ except: AlarmGUI = None
 ###############################################################################
 
 def getThemeIcon(icon):
-    if 3 == int(taurus.Release().version_info[0]):
-        from taurus.qt.qtgui import resource
-        if ':' in icon:
-            icon = resource.getIcon(icon)
-        else:
-            icon = resource.getThemeIcon(icon)
-    else:
-        if ':' in icon:
+    if ':' in icon:
             icon = icon.replace('/',':').strip(':')
             icon = Qt.QIcon(icon)
-        else:
+    else:
             icon = Qt.QIcon.fromTheme(icon)
     return icon
   
@@ -75,9 +69,9 @@ def getIconForAlarm(alarm):
 
 ###############################################################################
 
-class GuiWidget(QtGui.QWidget):
+class GuiWidget(QWidget):
     def __init__(self,parent=None):
-        QtGui.QWidget.__init__(self,parent)
+        QWidget.__init__(self,parent)
         self._gui = AlarmGUI()
         self._gui.setRowModels()
 
@@ -139,8 +133,8 @@ class AlarmValueLabel(Qt.QLabel):#TaurusValueLabel):
         #TaurusBaseWidget.updateStyle(self)
 
     def alarmUpdated(self):
-        #print('AlarmValueLabel.alarmUpdated()')
-        self.emit(Qt.SIGNAL('alarmUpdated'))        
+        print('AlarmValueLabel.alarmUpdated()')
+        #self.emit(Qt.SIGNAL('alarmUpdated'))
         
         
 ###############################################################################
@@ -177,7 +171,7 @@ class ToolbarActionButton(TaurusBaseComponent, Qt.QPushButton):
         self.setIcon(self.getIcon('OFF'))
 
     def getIcon(self,url):
-        print "ToolbarAction.getIcon(%s)"%url
+        print("ToolbarAction.getIcon(%s)"%url)
         if url in self.LEDS: url = self.LEDS[url]
         icon = taurus.qt.qtgui.resource.getIcon(url)
         return icon
@@ -238,13 +232,15 @@ class ToolbarActionButton(TaurusBaseComponent, Qt.QPushButton):
                     print('acknowledging %s with comment: %s !' %(self.name, comment))
                     taurus.Device(self.getModel().rsplit('/',1)[0]).command_inout('Acknowledge',[str(self.name), str(comment)])
                 except:
-                    print traceback.format_exc()
+                    print(traceback.format_exc())
             else:
-                Qt.QMessageBox.critical(self,"Error!",'Comment too short.\nAlarm not acknowledged.', QtGui.QMessageBox.AcceptRole, QtGui.QMessageBox.AcceptRole)
+                Qt.QMessageBox.critical(self,"Error!",'Comment too short.\nAlarm not acknowledged.', 
+                                        QtGui.QMessageBox.Ok)
         elif not ok:
             pass
         else:
-            Qt.QMessageBox.information(self,"Info!",'Alarm already acknowldged.', QtGui.QMessageBox.AcceptRole, QtGui.QMessageBox.AcceptRole)
+            Qt.QMessageBox.information(self,"Info!",'Alarm already acknowldged.', 
+                                       QtGui.QMessageBox.Ok)
 
     def onDisable(self):
         print('onDisable')
@@ -257,7 +253,8 @@ class ToolbarActionButton(TaurusBaseComponent, Qt.QPushButton):
                 comment='DISABLED by '+str(getpass.getuser())
                 taurus.Device(self.getModel().rsplit('/',1)[0]).command_inout('Disable', [str(self.name), str(comment)])
         else:
-            Qt.QMessageBox.information(self,"Info!",'Alarm already disabled.', QtGui.QMessageBox.AcceptRole, QtGui.QMessageBox.AcceptRole)
+            Qt.QMessageBox.information(self,"Info!",'Alarm already disabled.', 
+                                       QtGui.QMessageBox.Ok)
 
     def onReset(self):
         print('onReset')
@@ -271,11 +268,12 @@ class ToolbarActionButton(TaurusBaseComponent, Qt.QPushButton):
                 print('reseting %s with comment: %s !' %(self.name, comment))
                 taurus.Device(self.getModel().rsplit('/',1)[0]).command_inout('ResetAlarm',[str(self.name), str(comment)])
             except:
-                print traceback.format_exc()
+                print(traceback.format_exc())
         elif not ok:
             pass
         else:
-            Qt.QMessageBox.critical(self,"Error!",'Comment too short.\nAlarm not reseted.', QtGui.QMessageBox.AcceptRole, QtGui.QMessageBox.AcceptRole)
+            Qt.QMessageBox.critical(self,"Error!",'Comment too short.\nAlarm not reseted.', 
+                                    QtGui.QMessageBox.Ok)
 
     def onEdit(self):
         print('onEdit')
@@ -320,7 +318,7 @@ class PanicToolbar(TaurusBaseWidget, Qt.QToolBar):
                 if line.startswith(alarm+':'):
                     res = line.split(':')
                     break
-        except Exception,e:
+        except Exception:
             print ('Cant get the alarm date!')
         return res
             
@@ -329,14 +327,14 @@ class PanicToolbar(TaurusBaseWidget, Qt.QToolBar):
             if self.gui is None: self.gui = GuiWidget()
             self.gui.show()
           except:
-            print traceback.format_exc()
-            print 'AlarmGUI not available in PYTHONPATH'
+            print( traceback.format_exc())
+            print('AlarmGUI not available in PYTHONPATH')
             import os
             os.system('panic &')
           return self.gui 
 
     def setup(self,filters=None,api=None):#, alarms=None):
-        print "In PanicToolbar.setup(%s)"%filters
+        print("In PanicToolbar.setup(%s)"%filters)
         self.setMovable(True)
         self.setFloatable(True)
         filters = filters or self.filters
@@ -367,15 +365,15 @@ class PanicToolbar(TaurusBaseWidget, Qt.QToolBar):
                     if any(fandango.functional.matchCl(f,a) for f in self.filters for a in (attrs if '/' in f else tags)):
                         self.alarms.append(alarm)
             except:
-                print 'In PanicToolbar.filter_alarms(): Unable to parse %s:\n%s'%(alarm,traceback.format_exc())
+                print('In PanicToolbar.filter_alarms(): Unable to parse %s:\n%s'%(alarm,traceback.format_exc()))
                 
-        if self.alarms: print 'In PanicToolbar.refresh(): %d alarms out of %d matches filters'%(len(self.alarms),len(self.api.keys()))
-        else: print 'In PanicToolbar.refresh(): no Alarm matches %s'%self.filters
+        if self.alarms: print('In PanicToolbar.refresh(): %d alarms out of %d matches filters'%(len(self.alarms),len(self.api.keys())))
+        else: print('In PanicToolbar.refresh(): no Alarm matches %s'%self.filters)
         
         return self.alarms
 
     def refresh(self):
-        print 'In PanicToolbar.refresh(): filters = %s'%self.filters
+        print('In PanicToolbar.refresh(): filters = %s'%self.filters)
         
         if not self.filters: #(alarms!='*'):
             self.filters=[]
@@ -386,7 +384,7 @@ class PanicToolbar(TaurusBaseWidget, Qt.QToolBar):
         
         visible=0
         def sorter(obj):
-            print '%s -> %s' % (obj.tag, obj.active)
+            print('%s -> %s' % (obj.tag, obj.active))
             quality = self.api[obj.tag].get_quality()
             
             #full_attr_name = obj.device+'/'+obj.get_attribute()
@@ -417,13 +415,13 @@ class PanicToolbar(TaurusBaseWidget, Qt.QToolBar):
         self.addWidget(label)
         self.setToolTip("PanicToolbar: %s"%str(self.filters))
         url = os.path.dirname(panic.__file__)+'/'+"panic-icon.gif"
-        print '\t%s'%url
+        print('\t%s'%url)
         self.addAction(Qt.QIcon(url),'',self.showGui)
 
         for a,alarm in ordered:
-            if (visible>=self.max_visible): break
+            if visible>=self.max_visible: break
             if a in self.buttons: continue
-            print 'In PanicToolbar.refresh(): adding %s'%alarm
+            print('In PanicToolbar.refresh(): adding %s'%alarm)
             self.buttons[a] = ToolbarActionButton(self.gui,self.api)
             model = alarm.device+'/'+alarm.get_attribute()
             self.buttons[a].setAlarmModel(a)
@@ -477,7 +475,7 @@ if __name__ == '__main__':
             tmw.setCentralWidget(label)
             tmw.show()
         tmw.setMinimumWidth(600)
-        print '*'*80
+        print('*'*80)
         tmw.setWindowTitle('Alarm Toolbar')
         toolbar = PanicToolbar(tmw,filters=filters)
         tmw.addToolBar(toolbar)
